@@ -29,7 +29,7 @@ class QueryProcessor(object):
                                        include_pk=self.include_pk)
 
         if queryset is None:
-            queryset = trees[self.tree].get_queryset().values('pk')
+            queryset = trees[self.tree].get_queryset()
 
         return queryset
 
@@ -89,6 +89,9 @@ class QueryProcessors(object):
             self._processors[key] = klass
         return self._processors[key]
 
+    def __iter__(self):
+        return iter(self.processors)
+
     @property
     def default(self):
         return self[QUERY_PROCESSOR_DEFAULT_ALIAS]
